@@ -3,8 +3,10 @@ use strict;
 use warnings;
 use warnings::register;
 
+use v5.006;
+
 # ABSTRACT: An extension of the File::stat module, provides additional methods.
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 #pod =for test_synopsis
 #pod my ($st, $file);
@@ -223,11 +225,27 @@ sub lstat(*) { ## no critic (Subroutines::ProhibitSubroutinePrototypes)
 #pod =cut
 
 BEGIN {
+    no strict 'refs'; ## no critic (TestingAndDebugging::ProhibitNoStrict)
+
     # Define the main field accessors and the cando method using the File::stat version
     for my $f (qw(dev ino mode nlink uid gid rdev size atime mtime ctime blksize blocks cando)) {
-        no strict 'refs'; ## no critic (TestingAndDebugging::ProhibitNoStrict)
         *{$f} = sub { $_[0][0]->$f; }
     }
+
+#pod =for Pod::Coverage S_ISBLK S_ISCHR S_ISDIR S_ISFIFO S_ISLNK S_ISREG S_ISSOCK
+#pod
+#pod =cut
+
+    # Create own versions of these functions as they will croak on use
+    # if the platform doesn't define them. It's important to avoid
+    # inflicting that on the user.
+    # Note: to stay (more) version independent, we do not rely on the
+    # implementation in File::stat, but rather recreate here.
+    for (qw(BLK CHR DIR LNK REG SOCK)) {
+        *{"S_IS$_"} = defined eval { &{"Fcntl::S_IF$_"} } ? \&{"Fcntl::S_IS$_"} : sub { '' };
+    }
+    # FIFO flag and macro don't quite follow the S_IF/S_IS pattern above
+    *{'S_ISFIFO'} = defined &Fcntl::S_IFIFO ? \&Fcntl::S_ISFIFO : sub { '' };
 }
 
 #pod =method file
@@ -288,8 +306,7 @@ sub filetype {
 #pod =cut
 
 sub isFile {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISREG($_[0]->mode);
+    return S_ISREG($_[0]->mode);
 }
 
 *isRegular = *isFile;
@@ -301,8 +318,7 @@ sub isFile {
 #pod =cut
 
 sub isDir {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISDIR($_[0]->mode);
+    return S_ISDIR($_[0]->mode);
 }
 
 #pod =method isLink
@@ -314,8 +330,7 @@ sub isDir {
 #pod =cut
 
 sub isLink {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISLNK($_[0]->mode);
+    return S_ISLNK($_[0]->mode);
 }
 
 #pod =method isBlock
@@ -325,8 +340,7 @@ sub isLink {
 #pod =cut
 
 sub isBlock {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISBLK($_[0]->mode);
+    return S_ISBLK($_[0]->mode);
 }
 
 #pod =method isChar
@@ -336,8 +350,7 @@ sub isBlock {
 #pod =cut
 
 sub isChar {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISCHR($_[0]->mode);
+    return S_ISCHR($_[0]->mode);
 }
 
 #pod =method isFIFO
@@ -349,8 +362,7 @@ sub isChar {
 #pod =cut
 
 sub isFIFO {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISFIFO($_[0]->mode);
+    return S_ISFIFO($_[0]->mode);
 }
 
 *isPipe = *isFIFO;
@@ -362,8 +374,7 @@ sub isFIFO {
 #pod =cut
 
 sub isSocket {
-    # We make use of the File::stat version of the test to prevent unwanted croaks
-    return  File::stat::S_ISSOCK($_[0]->mode);
+    return S_ISSOCK($_[0]->mode);
 }
 
 #pod =method -X operator
@@ -426,9 +437,9 @@ my %op = (
     A => sub { -A $_[0][0] },
 
     # Implement these operators by testing the underlying file, caching the result
-    t => sub { $_[0][2] // -t $_[0]->file }, ## no critic (InputOutput::ProhibitInteractiveTest)
-    T => sub { $_[0][3] // -T $_[0]->file },
-    B => sub { $_[0][4] // -B $_[0]->file },
+    t => sub { defined $_[0][2] ? $_[0][2] : $_[0][2] = (-t $_[0]->file) || 0 }, ## no critic (InputOutput::ProhibitInteractiveTest)
+    T => sub { defined $_[0][3] ? $_[0][3] : $_[0][3] = (-T $_[0]->file) || 0 },
+    B => sub { defined $_[0][4] ? $_[0][4] : $_[0][4] = (-B $_[0]->file) || 0 },
 );
 
 use overload
@@ -466,7 +477,7 @@ File::stat::Extra - An extension of the File::stat module, provides additional m
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -701,6 +712,8 @@ do not, since the information required is not available.
 
 =back
 
+=for Pod::Coverage S_ISBLK S_ISCHR S_ISDIR S_ISFIFO S_ISLNK S_ISREG S_ISSOCK
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
